from datetime import date

class Hicham(): 
  
    def age(self):
        
        current_year = date.today().year
        
        print("age = " + str(current_year-1997))
        
    def nom(self): 
        
        print("nom : ZEKRI")
        
    def prenom(self): 
        
        print("prénom : Sidi Mohamed Hicham")
        
    def fonction(self): 
        
        print( "informaticien")
        