from setuptools import setup


requires = []


setup(
    name='hicham',
    version='0.2',
    description='Awesome library',
    url='',
    author='zekri sidi mohamed hicham',
    author_email='h.zekri@esi-sba.dz',
    license='MIT',
    keywords='this is me',
    packages=[
        "hicham"
    ],
    install_requires=requires,

)